%Generate a bubble distribution based on a Rayleigh distribution

close
maxDia=12;
step=0.05;
D=[0:step:maxDia]; % Diameter interval

p=raylpdf(D,2.3); % Generate the Rayleigh probability density distribution
% The number in the paranthesis is the mode and can be changed to get 
% the desired distribution 


%Generate cumulative diameter distribution by summing up density values:
DiaDist=p/sum(p);
CumDiaDist(1)=DiaDist(1);
i=2;
for i=2:(maxDia/step+1)
    CumDiaDist(i)=CumDiaDist(i-1)+DiaDist(i);
    i=i+1;
end
CumDiaDist=CumDiaDist*100;
CoeffDia=polyfit(D,CumDiaDist,8);

% Generate cumulative volume distribution by summing up the volumes to the
% corresponding distribution values: 
Volume=(pi/6)*D.^3;
i=1;

for i=1:(maxDia/step+1)
    Volumepart(i)=p(i)*Volume(i);
    
    i=i+1;
end

sumVolumepart=sum(Volumepart);

VolumeDist=Volumepart/sumVolumepart;

CumVolDist(1)=VolumeDist(1);
i=2;
for i=2:(maxDia/step+1)
    CumVolDist(i)=CumVolDist(i-1)+VolumeDist(i);
    i=i+1;
end
CumVolDist=100*CumVolDist;

CoeffVol=polyfit(D,CumVolDist,8);


%Generate plot of the three distributions:
scnsize=get(0,'ScreenSize');

figure('Name', 'Bubble and Volume Distribution', 'NumberTitle', 'off', ...
    'Position',[1 scnsize(4)/3 scnsize(3)/1.5 scnsize(4)/2])
sub1=subplot(1,3,1,'position',[0.04 0.1100 0.27 0.8]); ...
    plot(D,100*p,'LineWidth',1.5)
axis ('tight', 'square');
title('Bubble Distribution')
xlabel('Diameter [mm]')
ylabel('(ni/N) %')
sub2=subplot(1,3,2,'position',[0.37 0.1100 0.27 0.8]); ...
    plot(D,CumDiaDist,'LineWidth',1.5)
axis ('tight', 'square');
title('Cumulative Bubble Distribution')
xlabel('Diameter [mm]')
ylabel('Bubble %')
sub3=subplot(1,3,3,'position',[0.70 0.1100 0.27 0.80]); ...
    plot(D,CumVolDist,'LineWidth',1.5)
axis ('tight', 'square');
title('Cumulative Volume Distribution')
xlabel('Diameter [mm]')
ylabel('Volume %')





