% Horizontal separator with bubble distribtion from specificed values.
% Retention time as input.

run BubbleDistributionInput %Calls the bubble distribution script

%Set separator characteristics:
disp(' ')
disp('Specify separator properties: ')
L=input('Separator length[m]: ');
R=input('Separator raduis[m]: ');
Q=input('Flowrate[m3/s]: ');
t=input('Retention time[s]: ');
n=input('number of segments: ');

Actot=Q*t/L; %Total liquid cross sectional area

% Check if total liquid cross sectional area is bigger than total cross
% sectional area of separator:
while Actot>pi*(R^2)
     disp('Liquid height is higher than separator height')
     t=input('Choose new retention time[s]: ');
     Actot=Q*t/L;
end

%Determine theta for total cross section
theta=pi/2;
diff=1;
while diff>0.0001
    theta1=(Actot/R^2)+0.5*sin(2*theta);
    diff=abs(theta1-theta);
    theta=theta1;
end

%Calculate the last separator characteristics:
H=R*(1-cos(theta));
Hn=H/n;
Vh=Q/Actot;
Vhcm=Vh*100;

%Display calculated separator characteristics: 
disp(' ')
disp(['Cross sectional liquid area: ' num2str(Actot) ' m2'])
disp(['Liquid height: ' num2str(H) ' m'])
disp(['Height of each segment: ' num2str(Hn) ' m'])
disp(['Horizontal velocity: ' num2str(Vhcm) ' cm/s'])
disp(' ')

%Inputs detmerining the relative density of bubbles in each segment:
disp(['Specify percent of gas relative to each segment ' ...
    '(density of bubbles in each segment)'])
i=1;
for i=1:n
    SegmentPercent(i)=input(['Segment with height from '...
        num2str((i-1)*Hn) 'm to ' num2str(i*Hn) 'm: ']);
end

%Procedure for determining the required bubble terminal velocity in each
%segment and the corresponding bubble diameter. The diameter is found by
%using the correlation by Karamanev:
i=1;
Vv=[1:1:n];
for i=1:n
     Vv(i)=((H-Hn*(i-1))/L)*Vh; % Bubble velocity form each segment 

    de(i)=0.0001;
prop=1;
iterations=1;
while prop<1.0001 && n<10000 % Iteration procedure
    de(i)=de(i)+0.00015;
    
    Ar=g*rl*(de(i)^3)*(rl-rg)/(my^2);
    
    if Ar<13000
        Cd=(432/Ar)*(1+0.0470*(Ar^(2/3)))+0.517/(1+154*(Ar^(-1/3)));
    else
        Cd = 0.95;
    end
    
    Re=rl*Vv(i)*de(i)/my;
    
    M=g*(my^4)*(rl-rg)/((rl^2)*(sig^3));
    
    Ta=Re*M^0.23;
    
    if Ta<=2.11;
        dedh=1;
        elseif Ta<=5.46
        dedh=1.14*Ta^-0.176;
        elseif Ta<=16.53
        dedh=1.36*Ta^-0.28;
        else
        dedh=0.62;
    end
    
    ut1=(((4/3)*g*de(i)/Cd)^0.5)*dedh;
    
    prop=ut1/Vv(i);
   
    iterations=iterations+1;
end
    i=1+1;
end


% Adjustments for easier display of results 
Vv=Vv';
de=de';
Vvcm=Vv*100;
demm=de*1000;


% Displaying results:

% Velocity and corresponding minimum bubble diameter which will 
% get separated from the bottom of each segment. 
list=[0:1:n-1]';
Height=list*Hn;
result1=horzcat(flipud(Height),flipud(Vvcm),flipud(demm));
disp(' ')
disp(['Minimum terminal velocity with corresponding '... 
 'minimum bubble diameter at each height:'])
disp(' ')
disp('     H[m]     u[cm/s]   De[mm]')
disp(result1)


% Percentage share of bubbles from bottom of each segment that gets
% separated:
Diapercent=100-interp1(Dmean,CumDiaDist,demm);
result2=horzcat(flipud(Height),flipud(Diapercent));
disp(' ')
disp('Percentage share of bubbles from each segment that reach surface')
disp(' ')
disp('     H[m]     %')
disp(result2)

% Percent share of original gas volume in each segment that gets separated: 
Volumepercent=(100-interp1(Dmean,CumVolDist,demm));
result3=horzcat(flipud(Height),flipud(Volumepercent));
disp(' ')
disp('Percent of volume form each segment which is separated')
disp(' ')
disp('     H[m]     %')
disp(result3)


% Summing up to get the total volume separated. Has to be weighted in order
% to include the effect of different volumes and density of bubbles in 
% each segment: 
Height2=H-list*Hn;
i=1;
for i=1:n
    thetai(i)=acos(1-(Height2(i)/R));
    Ac(i)=(R^2)*thetai(i)-0.5*(R^2)*sin(2*thetai(i)); %Total area at height
end

i=1;
for i=1:n-1
    Acpart(i)=Ac(i)-Ac(i+1);
end
Acpart(i+1)=Ac(i+1);

Volumepartfraction=Acpart/Actot;
    
i=1;
for i=1:n
VolumepartfractiontimesSegmentpercent(i)= ... 
    Volumepartfraction(i)*SegmentPercent(i);
i=i+1;
end
Segmentfraction=VolumepartfractiontimesSegmentpercent/ ... 
    sum(VolumepartfractiontimesSegmentpercent);

i=1;
for i=1:n
Segmentseparated(i)=Segmentfraction(i)*Volumepercent(i);
i=i+1;
end

TotVolSep=(sum(Segmentseparated));
TotVolUnsep=100-TotVolSep;

% Display the final result:
disp(['Amount of gas seperated out: ' num2str(TotVolSep) ' %' ])
disp(['i.e. ' num2str(TotVolUnsep) ' % of the ' ... 
    'inlet GVF is still in the oil' ])


run EndDistribution2


